Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
herkules / HerkulesWorkerFind.py | HerkulesWorkerFind |  | 90% | 71 | 7 | 0 |  | 91% | 46 | 0 |  | 91%
Total |  |  | 92% | 91 | 7 | 0 |  | 91% | 46 | 0 |  | 92%

No items found using the specified filter.

1 class skipped due to complete coverage.